/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsISecretDecoderRin">
 **/

package org.mozilla.xpcom;

public interface nsISecretDecoderRingConfig extends nsISupports
{
  public static final String NS_ISECRETDECODERRINGCONFIG_IID =
    "{01d8c0f0-0ccc-11d4-9fdd-000064657374}";

  public void setWindow(nsISupports arg1);

}
